REMARK TEMPLATE
REMARK CLUSTER 1_3_3
REMARK REPRESENTING 1 CATALYTIC SITES
REMARK ID 3r6v_A187-B141-C318-A188-C319-B142-C324-B140-B101
REMARK MCSA_ID 1003
REMARK PDB_ID 3r6v
REMARK UNIPROT_ID Q9LCC6
REMARK EC 4.3.1.1
REMARK ENZYME Aspartase (E.C.4.3.1.1)
REMARK EXPERIMENTAL_METHOD X-ray diffraction
REMARK RESOLUTION 2.6
REMARK ORGANISM_NAME Bacillus sp.
REMARK ORGANISM_ID 96471
ATOM      3  CA ZTHR B 141     -18.537 -18.286 -15.536 T     0.00 
ATOM      3  CB ZTHR B 141     -17.147 -18.122 -16.162 T     0.00 
ATOM      1  OG1ZTHR B 141     -16.825 -19.284 -16.930 T     0.00 
ATOM      3  CG ZASN B 142     -18.297 -13.788 -17.020 N     0.00 
ATOM      1  OD1ZASN B 142     -17.239 -14.286 -16.628 N     0.00 
ATOM      1  ND2ZASN B 142     -18.458 -13.353 -18.256 N     0.00 
ATOM      3  CA ZSER B 140     -21.889 -18.528 -17.302 S     0.00 
ATOM      3  CB ZSER B 140     -21.996 -17.055 -17.678 S     0.00 
ATOM      1  OG ZSER B 140     -20.728 -16.434 -17.738 S     0.00 
END
